@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11199 2018-08-11 16:11:45Z Lavender $
+# $Id: models.py 11234 2018-09-29 12:58:04Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-08-12 01:11:45 +0900 (週日, 12 八月 2018) $
-# $Revision: 11199 $
+# $Date: 2018-09-29 21:58:04 +0900 (週六, 29 九月 2018) $
+# $Revision: 11234 $
 
 from functools import wraps
 from django import forms
@@ -45,6 +45,9 @@ class FilterPlugin(CMSPlugin):
         default=None,
         blank=True,
         null=True,
+        help_text=_(
+            "If you check 'Not use tags to filter article'. "
+            "It will no effect.")
     )
 
     catagory = models.ForeignKey(
@@ -55,6 +58,22 @@ class FilterPlugin(CMSPlugin):
         default=None,
         blank=True,
         null=True,
+        help_text=_(
+            "If you check 'Not use catagories to filter articles'. "
+            "It will no effect.")
+    )
+
+    allTag = models.BooleanField(
+        _('Not use tags to filter articles'), 
+        default=True,
+        help_text=_(
+            'If you check this. It will not filter articles with tags.')
+    )
+    allCatagory = models.BooleanField(
+        _('Not use catagories to filter articles'), 
+        default=True,
+        help_text=_(
+            'If you check this. It will not filter articles with catagories.')
     )
 
     renderTemplate = models.CharField(
@@ -63,6 +82,13 @@ class FilterPlugin(CMSPlugin):
         default=_settings.ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE,
     )
 
+class DatePluginConfig(CMSPlugin):
+    renderTemplate = models.CharField(
+        _('Render template'), max_length=150,
+        choices=_settings.ZEPHYRUS_BLOG_DATE_TEMPLATES,
+        default=_settings.ZEPHYRUS_BLOG_DATE_DEFAULT_TEMPLATE,
+    )
+
 class ViewCount(models.Model):
     url = models.CharField(max_length=400, editable=False)
     count = models.PositiveIntegerField(default=0)
