@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: assign_templates.py 10628 2017-12-10 13:03:41Z Lavender $
+# $Id: append_template.py 11055 2018-05-14 09:46:32Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-10 21:03:41 +0800 (週日, 10 十二月 2017) $
-# $Revision: 10628 $
+# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
+# $Revision: 11055 $
 
 import os
 import shutil
@@ -100,6 +100,10 @@ class Command(BaseCommand):
         bak = os.path.join(settingsDir, 'settings.py.bak')
         if os.path.isfile(bak):
             logger.error("%s exists. failed to backup file." % bak)
+            shutil.rmtree(os.path.join(staticDir, pageName))
+            shutil.rmtree(os.path.join(templateDir, pageName))
+            shutil.rmtree(hashDir)
+            os.remove('template.zip')
             return 
 
         shutil.copyfile(settingsPath, bak)
@@ -134,3 +138,9 @@ CMS_TEMPLATES += [
         call_command(
             'pluginize', template='index_content.html', templateDir=pageName)
 
+        page.template = '%s/index.html' % pageName
+        page.save()
+
+        shutil.rmtree(hashDir)
+        os.remove('template.zip')
+
