@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10994 2018-04-29 07:35:56Z Lavender $
+# $Id: pluginize.py 11011 2018-05-06 04:26:57Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-04-29 15:35:56 +0800 (週日, 29 四月 2018) $
-# $Revision: 10994 $
+# $Date: 2018-05-06 12:26:57 +0800 (週日, 06 五月 2018) $
+# $Revision: 11011 $
 
 import os
 import json
@@ -278,6 +278,11 @@ class Command(BaseCommand):
                 '-t', '--template', 
                 type=str,
                 help="template name.")
+
+        parser.add_argument(
+                '-d', '--templateDir', 
+                type=str,
+                help="template dir name.")
     
     def handle(self, language='', *args, **options):
         try:
@@ -298,7 +303,11 @@ class Command(BaseCommand):
             register.tags['placeholder'] = Placeholder2
             #register.tag(Placeholder2)
             
-            path = TEMPLATES_DIR_PATH
+            if options['templateDir']:
+                path = os.path.join(TEMPLATES_DIR_PATH, options['templateDir'])
+            else:
+                path = TEMPLATES_DIR_PATH
+
             logger.info('Processing...')
 
             if not os.path.exists(os.path.join(STATIC_DIR_PATH, 'js')):
